@@ -1,12 +1,10 @@
 # "pretty" names without the NAMESPACE_ prefixes...
 from __future__ import absolute_import
-
 from _sdl_image import lib
 
 __all__ = []
 
-def _init():
-    here = globals()
+def _mapping():
     import re
     constant = re.compile("IMG_[A-Z][A-Z]+")
     for name in dir(lib):
@@ -16,8 +14,13 @@ def _init():
             pretty_name = name[4:]
         else:
             pretty_name = name[4].lower() + name[5:]
+        yield name, pretty_name
+
+def _init():
+    here = globals()
+    for name, pretty_name in _mapping():
         here[pretty_name] = getattr(lib, name)
         __all__.append(pretty_name)
-        __all__.sort()
+    __all__.sort()
 
 _init()
\ No newline at end of file
